# MM-PTX Examples

The PTX Inject involved examples require [cuda-core](https://nvidia.github.io/cuda-python/cuda-core/latest/) to compile and run cuda code in python. Install cuda-core to your environment with
```bash
pip install cuda-core[cu11]
```
```bash
pip install cuda-core[cu12]
```
```bash
pip install cuda-core[cu13]
```

depending on your cuda toolkit supported version.

To get all of the examples working you'll need:

```bash
pip install Pillow opencv-python torch numpy
```
